@@ -2,7 +2,7 @@
 
 # maybe this module should be broken up into multiple files, or maybe not ...
 
-UA = "diffengine/0.0.30 (+https://github.com/docnow/diffengine)"
+UA = "diffengine/0.0.31 (+https://github.com/docnow/diffengine)"
 
 import os
 import re
@@ -148,7 +148,7 @@ class Entry(BaseModel):
         canonical_url = _remove_utm(resp.url)
 
         # get the latest version, if we have one
-        versions = EntryVersion.select().where(EntryVersion.entry==self)
+        versions = EntryVersion.select().where(EntryVersion.url==canonical_url)
         versions = versions.order_by(-EntryVersion.created)
         if len(versions) == 0:
             old = None
@@ -314,6 +314,7 @@ def setup_logging():
         filemode="a"
     )
     logging.getLogger("readability.readability").setLevel(logging.WARNING)
+    logging.getLogger("tweepy.binder").setLevel(logging.WARNING)
 
 def load_config(prompt=True):
     global config
